// Copyright 2007 - 2021, Alan Antonuk and the rabbitmq-c contributors.
// SPDX-License-Identifier: mit

/** \file */

#ifndef AMQP_SSL_H
#define AMQP_SSL_H

#ifdef _MSC_VER
#   pragma message("warning: amqp_ssl_socket.h is deprecated, use rabbitmq-c/ssl_socket.h instead.")
#else
#   warning "amqp_ssl_socket.h is deprecated, use rabbitmq-c/ssl_socket.h instead."
#endif

#include <rabbitmq-c/ssl_socket.h>

#endif /* AMQP_SSL_H */
